pub struct DecimalType {
pub scale: i32,
pub precision: i32,
}👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Decimal logical type annotation
Scale must be zero or a positive integer less than or equal to the precision. Precision must be a non-zero positive integer.
To maintain forward-compatibility in v1, implementations using this logical type must also set scale and precision on the annotated SchemaElement.
Allowed for physical types: INT32, INT64, FIXED_LEN_BYTE_ARRAY, and BYTE_ARRAY.
Fields
scale: i32👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
precision: i32👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Implementations
Sourceimpl DecimalType
impl DecimalType
pub fn new(scale: i32, precision: i32) -> DecimalType
👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0