pub struct FieldRepetitionType(pub i32);👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Representation of Schemas
Tuple Fields
0: i32👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0
Implementations
Sourceimpl FieldRepetitionType
impl FieldRepetitionType
Sourcepub const REQUIRED: FieldRepetitionType
👎Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
pub const REQUIRED: FieldRepetitionType
The format module is no longer maintained, and will be removed in 59.0.0
This field is required (can not be null) and each row has exactly 1 value.
Sourcepub const OPTIONAL: FieldRepetitionType
👎Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
pub const OPTIONAL: FieldRepetitionType
The format module is no longer maintained, and will be removed in 59.0.0
The field is optional (can be null) and each row has 0 or 1 values.
Sourcepub const REPEATED: FieldRepetitionType
👎Deprecated since 57.0.0: The format module is no longer maintained, and will be removed in 59.0.0
pub const REPEATED: FieldRepetitionType
The format module is no longer maintained, and will be removed in 59.0.0
The field is repeated and can contain 0 or more values
pub const ENUM_VALUES: &'static [Self]
👎Deprecated since 57.0.0:
The format module is no longer maintained, and will be removed in 59.0.0